==> distribution-6.0.0-dev.128.zip: drr/regulation/csa/rewrite/trade/reports/BasketConstituentIdentifierSourceRule.java <==
package drr.regulation.csa.rewrite.trade.reports;

import cdm.base.staticdata.asset.common.Commodity;
import cdm.base.staticdata.asset.common.Index;
import cdm.base.staticdata.asset.common.Loan;
import cdm.base.staticdata.asset.common.ProductIdTypeEnum;
import cdm.base.staticdata.asset.common.ProductIdentifier;
import cdm.base.staticdata.asset.common.Security;
import cdm.base.staticdata.asset.common.metafields.ReferenceWithMetaCommodity;
import cdm.base.staticdata.asset.common.metafields.ReferenceWithMetaProductIdentifier;
import cdm.product.template.BasketConstituent;
import com.google.inject.ImplementedBy;
import com.rosetta.model.lib.mapper.MapperC;
import com.rosetta.model.lib.mapper.MapperS;
import com.rosetta.model.lib.reports.ReportFunction;
import drr.regulation.common.functions.GetProductIdentifierFilteringISIN;
import javax.inject.Inject;

import static com.rosetta.model.lib.expression.ExpressionOperators.*;

@ImplementedBy(BasketConstituentIdentifierSourceRule.BasketConstituentIdentifierSourceRuleDefault.class)
public abstract class BasketConstituentIdentifierSourceRule implements ReportFunction<BasketConstituent, ProductIdTypeEnum> {
	
	// RosettaFunction dependencies
	//
	@Inject protected GetProductIdentifierFilteringISIN getProductIdentifierFilteringISIN;

	/**
	* @param input 
	* @return output 
	*/
	@Override
	public ProductIdTypeEnum evaluate(BasketConstituent input) {
		ProductIdTypeEnum output = doEvaluate(input);
		
		return output;
	}

	protected abstract ProductIdTypeEnum doEvaluate(BasketConstituent input);

	public static class BasketConstituentIdentifierSourceRuleDefault extends BasketConstituentIdentifierSourceRule {
		@Override
		protected ProductIdTypeEnum doEvaluate(BasketConstituent input) {
			ProductIdTypeEnum output = null;
			return assignOutput(output, input);
		}
		
		protected ProductIdTypeEnum assignOutput(ProductIdTypeEnum output, BasketConstituent input) {
			final MapperC<ReferenceWithMetaProductIdentifier> thenArg;
			if (exists(MapperS.of(input).<Security>map("getSecurity", basketConstituent -> basketConstituent.getSecurity())).getOrDefault(false)) {
				thenArg = MapperS.of(input).<Security>map("getSecurity", basketConstituent -> basketConstituent.getSecurity()).<ReferenceWithMetaProductIdentifier>mapC("getProductIdentifier", security -> security.getProductIdentifier());
			} else if (exists(MapperS.of(input).<Loan>map("getLoan", basketConstituent -> basketConstituent.getLoan())).getOrDefault(false)) {
				thenArg = MapperS.of(input).<Loan>map("getLoan", basketConstituent -> basketConstituent.getLoan()).<ReferenceWithMetaProductIdentifier>mapC("getProductIdentifier", loan -> loan.getProductIdentifier());
			} else if (exists(MapperS.of(input).<ReferenceWithMetaCommodity>map("getCommodity", basketConstituent -> basketConstituent.getCommodity())).getOrDefault(false)) {
				thenArg = MapperS.of(input).<ReferenceWithMetaCommodity>map("getCommodity", basketConstituent -> basketConstituent.getCommodity()).<Commodity>map("Type coercion", referenceWithMetaCommodity -> referenceWithMetaCommodity == null ? null : referenceWithMetaCommodity.getValue()).<ReferenceWithMetaProductIdentifier>mapC("getProductIdentifier", commodity -> commodity.getProductIdentifier());
			} else if (exists(MapperS.of(input).<Index>map("getIndex", basketConstituent -> basketConstituent.getIndex())).getOrDefault(false)) {
				thenArg = MapperS.of(input).<Index>map("getIndex", basketConstituent -> basketConstituent.getIndex()).<ReferenceWithMetaProductIdentifier>mapC("getProductIdentifier", index -> index.getProductIdentifier());
			} else {
				thenArg = MapperC.<ReferenceWithMetaProductIdentifier>ofNull();
			}
			output = MapperS.of(getProductIdentifierFilteringISIN.evaluate(thenArg.<ProductIdentifier>map("Type coercion", referenceWithMetaProductIdentifier -> referenceWithMetaProductIdentifier.getValue()).getMulti())).<ProductIdTypeEnum>map("getSource", productIdentifier -> productIdentifier.getSource()).get();
			
			return output;
		}
	}
}

==> distribution-6.17.1.zip: drr/regulation/csa/rewrite/trade/reports/BasketConstituentIdentifierSourceRule.java <==
package drr.regulation.csa.rewrite.trade.reports;

import cdm.base.staticdata.asset.common.ProductIdTypeEnum;
import cdm.product.template.BasketConstituent;
import com.google.inject.ImplementedBy;
import com.rosetta.model.lib.mapper.MapperS;
import com.rosetta.model.lib.reports.ReportFunction;
import javax.inject.Inject;


@ImplementedBy(BasketConstituentIdentifierSourceRule.BasketConstituentIdentifierSourceRuleDefault.class)
public abstract class BasketConstituentIdentifierSourceRule implements ReportFunction<BasketConstituent, ProductIdTypeEnum> {
	
	// RosettaFunction dependencies
	//
	@Inject protected drr.regulation.common.trade.basket.reports.BasketConstituentIdentifierSourceRule basketConstituentIdentifierSourceRule;

	/**
	* @param input 
	* @return output 
	*/
	@Override
	public ProductIdTypeEnum evaluate(BasketConstituent input) {
		ProductIdTypeEnum output = doEvaluate(input);
		
		return output;
	}

	protected abstract ProductIdTypeEnum doEvaluate(BasketConstituent input);

	public static class BasketConstituentIdentifierSourceRuleDefault extends BasketConstituentIdentifierSourceRule {
		@Override
		protected ProductIdTypeEnum doEvaluate(BasketConstituent input) {
			ProductIdTypeEnum output = null;
			return assignOutput(output, input);
		}
		
		protected ProductIdTypeEnum assignOutput(ProductIdTypeEnum output, BasketConstituent input) {
			output = MapperS.of(input)
				.mapSingleToItem(item -> MapperS.of(basketConstituentIdentifierSourceRule.evaluate(item.get()))).get();
			
			return output;
		}
	}
}
